@@ -24,11 +24,12 @@
 #define KALARM_KARECURRENCE_H
 
 #include "kalarmcal_export.h"
-#include <KDateTime>
-#include <kcalcore/recurrencerule.h>
-#include <kcalcore/duration.h>
-#include <kcalcore/incidencebase.h>
-namespace KCalCore
+#include "kadatetime.h"
+
+#include <kcalendarcore/recurrencerule.h>
+#include <kcalendarcore/duration.h>
+#include <kcalendarcore/incidencebase.h>
+namespace KCalendarCore
 {
 class Recurrence;
 }
@@ -42,7 +43,7 @@ namespace KAlarmCal
  * @short Represents recurrences for KAlarm.
  *
  * This class represents the restricted range of recurrence types which are
- * handled by KAlarm, and translates between these and the libkcalcore
+ * handled by KAlarm, and translates between these and the libkcalendarcore
  * Recurrence class. In particular, it handles yearly recurrences on 29th
  * February in non-leap years specially:
  *
@@ -50,7 +51,7 @@ namespace KAlarmCal
  * February or 1st March, or not at all, in non-leap years. It allows such
  * 29th February recurrences to be combined with the 29th of other months in
  * a simple way, represented simply as the 29th of multiple months including
- * February. For storage in the libkcalcore calendar, the 29th day of the month
+ * February. For storage in the libkcalendarcore calendar, the 29th day of the month
  * recurrence for other months is combined with a last-day-of-February or a
  * 60th-day-of-the-year recurrence rule, thereby conforming to RFC2445.
  *
@@ -60,7 +61,7 @@ class KALARMCAL_EXPORT KARecurrence
 {
 public:
     /** The recurrence's period type.
-     *  This is a subset of the possible KCalCore recurrence types.
+     *  This is a subset of the possible KCalendarCore recurrence types.
      */
     enum Type {
         NO_RECUR,      //!< does not recur
@@ -81,7 +82,7 @@ public:
     };
 
     KARecurrence();
-    KARecurrence(const KCalCore::Recurrence &r);
+    KARecurrence(const KCalendarCore::Recurrence &r);
     KARecurrence(const KARecurrence &r);
     ~KARecurrence();
 
@@ -121,14 +122,14 @@ public:
      *  weekly, monthly, yearly or none.
      *  @return true if successful.
      */
-    bool set(Type t, int freq, int count, const KDateTime &start, const KDateTime &end);
+    bool set(Type t, int freq, int count, const KADateTime &start, const KADateTime &end);
 
     /** Set up a KARecurrence from recurrence parameters, using the start date to
      *  determine the recurrence day/month as appropriate, and specifying how
      *  annual 29th February recurrences in non-leap years should be handled.
      *  @return true if successful.
      */
-    bool set(Type t, int freq, int count, const KDateTime &start, const KDateTime &end, Feb29Type f29);
+    bool set(Type t, int freq, int count, const KADateTime &start, const KADateTime &end, Feb29Type f29);
 
     /** Set up a KARecurrence from recurrence parameters.
      *  Annual 29th February recurrences in non-leap years will be handled
@@ -137,7 +138,7 @@ public:
      *  weekly, monthly, yearly or none.
      *  @return true if successful.
      */
-    bool init(KCalCore::RecurrenceRule::PeriodType t, int freq, int count, const KDateTime &start, const KDateTime &end);
+    bool init(KCalendarCore::RecurrenceRule::PeriodType t, int freq, int count, const KADateTime &start, const KADateTime &end);
 
     /** Set up a KARecurrence from recurrence parameters, specifying how
      *  annual 29th February recurrences in non-leap years should be handled.
@@ -145,18 +146,18 @@ public:
      *  weekly, monthly, yearly or none.
      *  @return true if successful.
      */
-    bool init(KCalCore::RecurrenceRule::PeriodType t, int freq, int count, const KDateTime &start, const KDateTime &end, Feb29Type f29);
+    bool init(KCalendarCore::RecurrenceRule::PeriodType t, int freq, int count, const KADateTime &start, const KADateTime &end, Feb29Type f29);
 
     /** Removes all recurrence and exception rules and dates. */
     void clear();
 
-    /** Initialise a KCalCore::Recurrence to be the same as this instance.
+    /** Initialise a KCalendarCore::Recurrence to be the same as this instance.
      *  Additional recurrence rules are created as necessary if it recurs on Feb 29th.
      */
-    void writeRecurrence(KCalCore::Recurrence &) const;
+    void writeRecurrence(KCalendarCore::Recurrence &) const;
 
     /** Convert the recurrence to KARecurrence types.
-     *  Must be called after presetting with a KCalCore::Recurrence.
+     *  Must be called after presetting with a KCalendarCore::Recurrence.
      *  - Convert hourly recurrences to minutely.
      *  - Remove all but the first day in yearly date recurrences.
      *  - Check for yearly recurrences falling on February 29th and adjust them as
@@ -168,7 +169,7 @@ public:
     /** Return the start date/time of the recurrence (Time for all-day recurrences will be 0:00).
      * @return the current start/time of the recurrence.
      */
-    KDateTime startDateTime() const;
+    KADateTime startDateTime() const;
 
     /** Return the start date/time of the recurrence */
     QDate startDate() const;
@@ -177,10 +178,10 @@ public:
      *  @param dt        start date/time.
      *  @param dateOnly  if true, sets the recurrence to all-day.
      */
-    void        setStartDateTime(const KDateTime &dt, bool dateOnly);
+    void        setStartDateTime(const KADateTime &dt, bool dateOnly);
 
     /** Return the date/time of the last recurrence. */
-    KDateTime   endDateTime() const;
+    KADateTime   endDateTime() const;
 
     /** Return the date of the last recurrence. */
     QDate       endDate() const;
@@ -194,7 +195,7 @@ public:
     /** Sets the date and time of the last recurrence.
      * @param endDateTime the ending date/time after which to stop recurring.
      */
-    void setEndDateTime(const KDateTime &endDateTime);
+    void setEndDateTime(const KADateTime &endDateTime);
 
     /** Set whether the recurrence has no time, just a date.
      * All-day means -- according to rfc2445 -- that the event has no time
@@ -218,7 +219,7 @@ public:
     QBitArray days() const; // Emulate the old behavior
 
     /** Returns list of day positions in months. */
-    QList<KCalCore::RecurrenceRule::WDayPos> monthPositions() const;
+    QList<KCalendarCore::RecurrenceRule::WDayPos> monthPositions() const;
 
     /** Returns list of day numbers of a  month. */
     // Emulate old behavior
@@ -258,7 +259,7 @@ public:
      *         Friday in the given months, otherwise as third Friday of the
      *         year.
      */
-    QList<KCalCore::RecurrenceRule::WDayPos> yearPositions() const;
+    QList<KCalendarCore::RecurrenceRule::WDayPos> yearPositions() const;
 
     /** Adds days to the weekly day recurrence list.
      * @param days a 7 bit array indicating which days on which to recur (bit 0 = Monday).
@@ -325,14 +326,14 @@ public:
     void addMonthlyDate(short day);
 
     /** Get the next time the recurrence occurs, strictly after a specified time. */
-    KDateTime   getNextDateTime(const KDateTime &preDateTime) const;
+    KADateTime   getNextDateTime(const KADateTime &preDateTime) const;
 
     /** Get the previous time the recurrence occurred, strictly before a specified time. */
-    KDateTime   getPreviousDateTime(const KDateTime &afterDateTime) const;
+    KADateTime   getPreviousDateTime(const KADateTime &afterDateTime) const;
 
     /** Return whether the event will recur on the specified date.
      *  The start date only returns true if it matches the recurrence rules. */
-    bool        recursOn(const QDate &, const KDateTime::Spec &) const;
+    bool        recursOn(const QDate &, const KADateTime::Spec &) const;
 
     /**
      * Returns true if the date/time specified is one at which the event will
@@ -340,7 +341,7 @@ public:
      *
      * @param dt is the date/time to check.
      */
-    bool recursAt(const KDateTime &dt) const;
+    bool recursAt(const KADateTime &dt) const;
 
     /** Returns a list of the times on the specified date at which the
      * recurrence will occur. The returned times should be interpreted in the
@@ -348,21 +349,21 @@ public:
      * @param date the date for which to find the recurrence times
      * @param timeSpec time specification for @p date
      */
-    KCalCore::TimeList recurTimesOn(const QDate &date, const KDateTime::Spec &timeSpec) const;
+    KCalendarCore::TimeList recurTimesOn(const QDate &date, const KADateTime::Spec &timeSpec) const;
 
     /** Returns a list of all the times at which the recurrence will occur
      * between two specified times.
      *
      * There is a (large) maximum limit to the number of times returned. If due to
      * this limit the list is incomplete, this is indicated by the last entry being
-     * set to an invalid KDateTime value. If you need further values, call the
+     * set to an invalid KADateTime value. If you need further values, call the
      * method again with a start time set to just after the last valid time returned.
      *
      * @param start inclusive start of interval
      * @param end inclusive end of interval
      * @return list of date/time values
      */
-    KCalCore::DateTimeList timesInInterval(const KDateTime &start, const KDateTime &end) const;
+    KCalendarCore::DateTimeList timesInInterval(const KADateTime &start, const KADateTime &end) const;
 
     /** Returns frequency of recurrence, in terms of the recurrence time period type. */
     int frequency() const;
@@ -384,7 +385,7 @@ public:
     /** Returns the number of recurrences up to and including the date/time specified.
      *  @warning This function can be very time consuming - use it sparingly!
      */
-    int durationTo(const KDateTime &dt) const;
+    int durationTo(const KADateTime &dt) const;
 
     /** Returns the number of recurrences up to and including the date specified.
      *  @warning This function can be very time consuming - use it sparingly!
@@ -394,18 +395,18 @@ public:
     /** Return the longest interval between recurrences.
      *  @return  0 if it never recurs.
      */
-    KCalCore::Duration longestInterval() const;
+    KCalendarCore::Duration longestInterval() const;
 
     /** Return the interval between recurrences, if the interval between
      *  successive occurrences does not vary.
      *  @return  0 if recurrence does not occur at fixed intervals.
      */
-    KCalCore::Duration regularInterval() const;
-    KCalCore::DateTimeList exDateTimes() const;
-    KCalCore::DateList exDates() const;
-    void setExDateTimes(const KCalCore::DateTimeList &exdates);
-    void setExDates(const KCalCore::DateList &exdates);
-    void addExDateTime(const KDateTime &exdate);
+    KCalendarCore::Duration regularInterval() const;
+    KCalendarCore::DateTimeList exDateTimes() const;
+    KCalendarCore::DateList exDates() const;
+    void setExDateTimes(const KCalendarCore::DateTimeList &exdates);
+    void setExDates(const KCalendarCore::DateList &exdates);
+    void addExDateTime(const KADateTime &exdate);
     void addExDate(const QDate &exdate);
 
     /**
@@ -424,15 +425,15 @@ public:
      */
     void shiftTimes(const QTimeZone &oldSpec, const QTimeZone &newSpec);
 
-    KCalCore::RecurrenceRule *defaultRRuleConst() const;
+    KCalendarCore::RecurrenceRule *defaultRRuleConst() const;
     /** Return the recurrence's period type. */
     Type type() const;
 
     /** Return the type of a recurrence rule. */
-    static Type type(const KCalCore::RecurrenceRule *);
+    static Type type(const KCalendarCore::RecurrenceRule *);
 
     /** Check if the recurrence rule is a daily rule with or without BYDAYS specified. */
-    static bool dailyType(const KCalCore::RecurrenceRule *);
+    static bool dailyType(const KCalendarCore::RecurrenceRule *);
 
     /** Return when 29th February annual recurrences should occur in non-leap years. */
     Feb29Type feb29Type() const;
@@ -460,3 +461,4 @@ private:
 
 #endif // KALARM_KARECURRENCE_H
 
+// vim: et sw=4:
